% -------------------------------------------------------------------------
% Worksheet for numerical experiments.
% -------------------------------------------------------------------------

% input data                                          % -------------------
clearvars; close all; clc; Data;                      % data ........ input
set(0,'defaulttextinterpreter','latex');              % Text ........ LaTeX

%{
%%%%% PART A %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% states                                              % -------------------
HatY = State(M,A,f,y0,dt);                            % HatY ........ NxxNt
Y1 = State(M,A,B*u0,zeros(Nx,1),dt);                  % Y1 .......... NxxNt
Y2 = State(M,A,f+B*u0,y0,dt);                         % Y2 .......... NxxNt
% POD                                                 % -------------------
Psi1 = Pod(dt,M,Y1,lmax);                             % Psi1 ...... Nxxlmax
Psi2 = Pod(dt,M,Y2,lmax);                             % Psi2 ...... Nxxlmax
% ROM                                                 % -------------------
for l = 1:lmax                                        % begin ......... for
  [Ml1,Al1,Bl1] = Rom(Psi1(:,1:l),M,A,B);             % Ml,Al,Bl ...... lx?
  [Ml2,Al2,Bl2,fl2,y0l2] = Rom(Psi2(:,1:l),M,A,B,f,y0); % fl,y0l ...... lx?
  xl1 = State(Ml1,Al1,Bl1*u0,zeros(l,1),dt);          % xl1 .......... lxNt
  xl2 = State(Ml2,Al2,fl2+Bl2*u0,y0l2,dt);            % xl2 .......... lxNt
  Yl1 = ...                                           % Yl1 ......... NxxNt
  Yl2 = ...                                           % Yl2 ......... NxxNt
  Error1(l) = Norm(Yl1-Y2,M,dt);                      % Error1(.) ..... 1x1
  Error2(l) = Norm(Yl2-Y2,M,dt);                      % Error2(.) ..... 1x1
end                                                   % end ........... for
% visualize                                           % -------------------
Visualize('State',{T,X,Y2});                          % State ......... fig
Visualize('Error',{Error1,Error2});                   % Error ......... fig
Visualize('Basis',{x,Psi1});                          % Psi1 .......... fig
Visualize('Basis',{x,Psi2});                          % Psi2 .......... fig
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%}

%{
%%%%% PART C %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Determine inhomogeneous data                        % -------------------
  HatY = ...; HatP = ...;                             % HatY,HatP ... NxxNt
% Calculate full solution UOpt                        % -------------------
  UOpt = Solver(...);                                 % UOpt ........ MuxNt
  Visualize('Control',{t,UOpt}); drawnow;             % Control ....... fig
% Calculate homogeneous snapshots Y                   % -------------------
  Y = State(...);                                     % Y ........... NxxNt
% Calculate POD basis Psi                             % -------------------
  Psi = Rom(...);                                     % Psi ....... Nxxlmax
% Reduced Order Modelling                             % -------------------
for l = 1:30                                          % begin ......... for
  fprintf('POD-OPT rank %3.0i\n',l)                   % rank l .... display
  % Assemble reduced order model Ml,Al,Bl             % -------------------
  [Ml,Al,Bl] = Rom(...);                              % Ml,Al,Bl ...... lx?
  % Calculate ROM solution Ul                         % -------------------
  Ul = Solver(...);                                   % Ul .......... MuxNt
  Error(l) = Norm(Ul-UOpt,speye(Mu),dt);              % Error(.) ...... 1x1
end                                                   % end ........... for
Visualize('RedOrdMod',{Error});                       % RedOrdMod ..... fig
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%}

% -------------------------------------------------------------------------
% Martin Gubisch
% 13.09.2013 --- 19:18