% -------------------------------------------------------------------------
% Determine POD basis with singular value decomposition.
%
% Input:
% dt ......................................... 1x1 time stepsize
% M .......................................... NxxNx mass matrix
% Y .......................................... NxxNt snapshots
% lmax ....................................... 1x1 maximal basis size
%
% Output:
% Psi ........................................ Nxxl POD basis elements
% -------------------------------------------------------------------------

function Psi = Pod(dt,M,Y,lmax)

  Nt = size(Y,2);                                  % Nt ............... 1x1
  Alpha = spdiags(dt*ones(Nt,1),0,Nt,Nt);    ...
    Alpha(1,1) = .5*dt; Alpha(end,end) = .5*dt;    % Alpha .......... NtxNt
  Weight = sqrtm(full(M));                         % Weight ......... NxxNx
  [UU,~,~] = svd(Weight*Y*sqrt(Alpha));              ...
  Psi = Weight\UU(:,1:lmax);                       % Basis ........... Nxxl

% -------------------------------------------------------------------------
% Martin Gubisch
% 12.09.2013 --- 17:16