% -------------------------------------------------------------------------
% Solve the optimization problem via a fixpoint iteration.
%
% Input:
% u0 ......................................... MuxNt initial control guess
% eps ........................................ 1x1 desired exactness
% kmax ....................................... 1x1 maximal iteration number
% M .......................................... NxxNx mass matrix
% A .......................................... NxxNx stiffness matrix
% B .......................................... NxxMu control operator
% dt ......................................... 1x1 time stepsize
% sigma ...................................... 1x1 regularization parameter
% ua,ub ...................................... MuxNt control bounds
% Bp ......................................... MuxNt U-independent inhom.
%
% Output:
% u .......................................... MuxNt optimal control
% -------------------------------------------------------------------------

function u = Solver(u0,eps,kmax,M,A,B,dt,sigma,ua,ub,Bp)

% ----- Initialize the system ---------------------------------------------
  Mu = size(u0,1); k = 0; u = u0;
  while k < kmax
   Y = State(M,A,B*u,zeros(size(M,1),1),dt);
   P = fliplr(State(M,A,-fliplr(Y),-Y(:,end),dt));
   uu = min(max((1/sigma)*(B'*P+Bp),ua),ub);
    if Norm(u-uu,speye(Mu),dt) < eps
      break
    end
    u = uu; k = k+1;
  end

% -------------------------------------------------------------------------
% Martin Gubisch
% 12.09.2013 --- 17:09