% -------------------------------------------------------------------------
% Implicit Euler method for linear parabolic equations of the form
% (d/dt)MY(t) + AY(t) = F(t) & MY(0) = Y0.
%
% Input:
% M .......................................... NxxNx mass matrix
% A .......................................... NxxNx stiffness matrix
% F .......................................... NxxNt inhomoegenity
% Y0 ......................................... Nxx1 initial value
% dt ......................................... 1x1 time stepsize
%
% Output:
% Y .......................................... NxxNt state solution
% -------------------------------------------------------------------------

function Y = State(M,A,F,Y0,dt)

% initialize
[Nx,Nt] = size(F); Y = zeros(Nx,Nt);
% initial value
Y(:,1) = M\Y0;
% provide implicit time steps
for ii = 1:Nt-1
  Y(:,ii+1) = (M/dt+A)\(M/dt*Y(:,ii)+F(:,ii+1));
end
  
% -------------------------------------------------------------------------
% Martin Gubisch
% 12.09.2013 --- 17:09