% -------------------------------------------------------------------------
% Visualize results from the worksheet.
% -------------------------------------------------------------------------

function Visualize(flag,Cell)

switch flag                                           % begin ...... switch
case 'State'                                          % case ....... switch
  Nt = size(Cell{3},2);                                 ...
  Y = [zeros(1,Nt);Cell{3};zeros(1,Nt)];                ...
  figure;                                               ...
  surf(Cell{1},Cell{2},Y); grid off; shading flat;      ...
  title('state solution');                              ...
  xlabel('time $t$'); ylabel('space $x$');              ...
  zlabel('state $y=y(t,x)$');                           ...
case 'Control'                                        % case ....... switch
  figure;                                               ...
  [T,X] = ndgrid(1:10,Cell{1});                         ...
  surf(T,X,Cell{2}); shading flat;                      ...
  xlim([1,10]); grid off;                               ...
  title('optimal controls');                            ...
  ylabel('time $t$'); xlabel('components $i$');         ...
  zlabel('control $u=u_i(t)$');                         ...
case 'Error'                                          % case ....... switch
  figure;                                               ...
  semilogy(1:length(Cell{1}),Cell{1},'r'); hold on;     ...
  semilogy(1:length(Cell{1}),Cell{2},'b');              ...
  title('POD Galerkin errors');                         ...
  legend('modified approximation error',                ...
    'classical approximation error',                    ...
    'location','NorthEast');                            ...
  xlabel('POD basis rank $\ell$');                      ...
  ylabel('Error($\ell$)');                              ...
case 'Basis'                                          % case ....... switch
  lmax = size(Cell{2},2);                               ...
  Psi = [zeros(1,lmax);Cell{2};zeros(1,lmax)];          ...
  figure; hold on; ylim([-3,3]);                        ...
  plot(Cell{1},Psi(:,1),'k');                           ...
  plot(Cell{1},Psi(:,2),'b');                           ...
  plot(Cell{1},Psi(:,3),'r');                           ...
  plot(Cell{1},Psi(:,4),'m');                           ...
  plot(Cell{1},Psi(:,5),'g');                           ...
  plot(Cell{1},Psi(:,6),'y');                           ...
  plot(Cell{1},Psi(:,7),'c');                           ...
  legend('$\psi_1(x)$','$\psi_2(x)$','$\psi_3(x)$',     ...
    '$\psi_4(x)$','$\psi_5(x)$','$\psi_6(x)$',          ...
    '$\psi_7(x)$','location','NorthEast');              ...
  xlabel('$x$'); ylabel('$\psi_l(x)$');                 ...
case 'RedOrdMod'                                      % case ....... switch
    figure;                                             ...
    semilogy(1:length(Cell{1}),Cell{1},'b');            ...
    title('ROM control errors');                        ...
    xlim([1,length(Cell{1})]);                          ...
    xlabel('POD basis rank $\ell$');                    ...
    ylabel('Error($\ell$)');                            ...
end                                                   % end ........ switch

% -------------------------------------------------------------------------
% Martin Gubisch
% 13.09.2013 --- 19:52